package enum

// FinWithdrawApplyState 提现单状态
type FinWithdrawApplyState int

const (
	FinWithdrawApplyStateForApply FinWithdrawApplyState = iota
	FinWithdrawApplyStateForPass
	FinWithdrawApplyStateForSuccess
	FinWithdrawApplyStateForBad
	FinWithdrawApplyStateForIng
)

func (kind FinWithdrawApplyState) String() string {
	switch kind {
	case FinWithdrawApplyStateForApply:
		return "申请中"
	case FinWithdrawApplyStateForPass:
		return "通过"
	case FinWithdrawApplyStateForSuccess:
		return "完成"
	case FinWithdrawApplyStateForBad:
		return "失败"
	case FinWithdrawApplyStateForIng:
		return "处理中"
	default:
		return "未知状态"
	}
}

// FinWithdrawApplyReason 提现单驳回理由
type FinWithdrawApplyReason int

const (
	FinWithdrawApplyReasonForNotRule FinWithdrawApplyReason = iota + 1
	FinWithdrawApplyReasonForAccountAbnormal
	FinWithdrawApplyReasonForFundAbnormal
)

func (kind FinWithdrawApplyReason) String() string {
	switch kind {
	case FinWithdrawApplyReasonForNotRule:
		return "当前账号不满足提现规则"
	case FinWithdrawApplyReasonForAccountAbnormal:
		return "账号异常"
	case FinWithdrawApplyReasonForFundAbnormal:
		return "资金异常"
	default:
		return "未知状态"
	}
}

// FinWithdrawApplyWithdrawKind 提现单提现方式
type FinWithdrawApplyWithdrawKind int

const (
	FinWithdrawApplyWithdrawKindForAli FinWithdrawApplyWithdrawKind = iota + 1
	FinWithdrawApplyWithdrawKindForWx
)

func (kind FinWithdrawApplyWithdrawKind) String() string {
	switch kind {
	case FinWithdrawApplyWithdrawKindForAli:
		return "alipay"
	case FinWithdrawApplyWithdrawKindForWx:
		return "wx"
	default:
		return "未知状态"
	}
}

// FinWithdrawApplyWithdrawConditionDissatisfyKind 提现不满足条件类型
type FinWithdrawApplyWithdrawConditionDissatisfyKind int

const (
	FinWithdrawApplyWithdrawConditionDissatisfyKindNotRealName = iota + 1
	FinWithdrawApplyWithdrawConditionDissatisfyKindNotEnoughLevel
	FinWithdrawApplyWithdrawConditionDissatisfyKindNotInTime
)

func (kind FinWithdrawApplyWithdrawConditionDissatisfyKind) String() string {
	switch kind {
	case FinWithdrawApplyWithdrawConditionDissatisfyKindNotRealName:
		return "用户未实名"
	case FinWithdrawApplyWithdrawConditionDissatisfyKindNotEnoughLevel:
		return "用户未达到提现等级"
	case FinWithdrawApplyWithdrawConditionDissatisfyKindNotInTime:
		return "不在提现时间"
	default:
		return "未知错误"
	}
}
