package md

const (
	CommentLikeCacheKey  = "comment:%s:like"
	CommentLikeCacheTime = 86400 * 30
)

const EggEnergyUserEggScoreEsAlias = "egg_energy_user_egg_score"

const EggEnergyUserEggScoreEsMapping = `
{ 
	"settings" : {
      "number_of_shards" : 2,
      "number_of_replicas" : 1 
    },
    "aliases": {
      "egg_energy_user_egg_score": {}
	},
	"mappings":{
		"properties":{
			"uid":{
				"type": "integer"
			},
			"score_value":{
				"type": "float"
			},
			"score_value_kind":{
				"type": "short"
			},
			"ecpm":{
				"type": "float"
			},
			"invite_user_nums":{
				"type": "integer"
			},
			"team_activity_nums":{
				"type": "integer"
			},
			"sign_in_nums":{
				"type": "short"
			},
			"im_activity_nums":{
				"type": "short"
			},
			"send_red_package_nums":{
				"type": "short"
			},
			"egg_energy_exchange_account_balance":{
				"type": "integer"
			},
			"account_balance_exchange_egg_energy_nums":{
				"type": "integer"
			},
			"send_circle_of_friend_nums":{
				"type": "short"
			},
			"forum_comments_nums":{
				"type": "integer"
			},
			"college_learning_nums":{
				"type": "short"
			},
			"violate_nums":{
				"type": "short"
			},
			"browse_interface_nums":{
				"type": "integer"
			},
			"person_add_activity_value":{
				"type": "integer"
			},
			"created_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"updated_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			}
		}
	}
}`

type EggEnergyUserEggScoreEs struct {
	Uid                                 int64   `json:"uid" label:"uid"`
	ScoreValue                          float64 `json:"score_value"  label:"蛋蛋分值"`
	ScoreValueKind                      int32   `json:"score_value_kind" label:"评分类型(0:未知 1:人工 2:系统)"`
	Ecpm                                float64 `json:"ecpm" label:"ecpm"`
	InviteUserNums                      int     `json:"invite_user_nums" label:"拉新人数"`
	TeamActivityNums                    int     `json:"team_activity_nums" label:"团队活跃次数"`
	SignInNums                          int     `json:"sign_in_nums" label:"签到次数"`
	ImActivityNums                      int     `json:"im_activity_nums" label:"im活跃次数"`
	SendRedPackageNums                  int     `json:"send_red_package_nums" label:"发红包次数"`
	EggEnergyExchangeAccountBalance     int     `json:"egg_energy_exchange_account_balance" label:"蛋蛋能量兑换余额数量"`
	AccountBalanceExchangeEggEnergyNums int     `json:"account_balance_exchange_egg_energy_nums" label:"余额兑换蛋蛋能量数量"`
	SendCircleOfFriendNums              int     `json:"send_circle_of_friend_nums" label:"发朋友圈次数"`
	ForumCommentsNums                   int     `json:"forum_comments_nums" label:"论坛评论次数"`
	CollegeLearningNums                 int     `json:"college_learning_nums" label:"学院学习次数"`
	ViolateNums                         int     `json:"violate_nums" label:"违规次数"`
	BrowseInterfaceNums                 int     `json:"browse_interface_nums" label:"浏览界面次数"`
	PersonAddActivityValue              int     `json:"person_add_activity_value" label:"个人活跃积分"`
	CreatedAt                           string  `json:"created_at"`
	UpdatedAt                           string  `json:"updated_at"`
}

const EggFriendCircleEsAlias = "egg_friend_circle"
const EggFriendCircleEsIndex = "egg_friend_circle_1"
const EggFriendCircleEsMapping = `
{ 
	"settings" : {
      "number_of_shards" : 2,
      "number_of_replicas" : 1 
    },
    "aliases": {
      "egg_friend_circle": {}
	},
	"mappings":{
		"properties":{
			"uid":{
				"type": "integer"
			},
			"im_uid":{
				"type": "integer"
			},
			"kind":{
				"type": "short"
			},
			"content":{
				"type": "text",
         		"analyzer": "ik_smart"
			},
			"image":{
				"type": "keyword"
			},
			"video":{
				"type": "keyword"
			},
			"likes_nums":{
				"type": "integer"
			},
			"comment_nums":{
				"type": "integer"
			},
			"share_nums":{
				"type": "integer"
			},
			"state":{
				"type": "short"
			},	
			"is_praise":{
				"type": "short"
			},		
			"is_top_up":{
				"type": "short"
			},
			"created_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"updated_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			}
		}
	}
}`

type EggFriendCircleEs struct {
	Uid         int64  `json:"uid" label:"uid"`
	ImUid       int64  `json:"im_uid" label:"im_uid"`
	Kind        int32  `json:"kind"  label:"类型(1:普通 2:官方)"`
	Content     string `json:"content" label:"文本内容"`
	Image       string `json:"image" label:"图片"`
	Video       string `json:"video" label:"视频"`
	LikesNums   int    `json:"likes_nums" label:"点赞数"`
	ShareNums   int    `json:"share_nums" label:"分享数"`
	CommentNums int    `json:"comment_nums" label:"评论数"`
	State       int32  `json:"state" label:"状态(1:正常 2:隐藏)"`
	IsTopUp     int32  `json:"is_top_up" label:"是否置顶(1:是 2:否)"`
	IsPraise    int32  `json:"is_praise" label:"是否被表扬(1:是 2:否)"`
	CreatedAt   string `json:"created_at"`
	UpdatedAt   string `json:"updated_at"`
}

const EggFriendCircleCommentEsAlias = "egg_friend_circle_comment"
const EggFriendCircleCommentEsIndex = "egg_friend_circle_comment_"
const EggFriendCircleCommentEsMapping = `
{ 
	"settings" : {
      "number_of_shards" : 2,
      "number_of_replicas" : 1 
    },
    "aliases": {
      "egg_friend_circle_comment": {}
	},
	"mappings":{
		"properties":{
			"uid":{
				"type": "integer"
			},
			"im_uid":{
				"type": "integer"
			},
			"circle_id":{
				"type": "keyword"
			},
			"comment_id":{
				"type": "keyword"
			},
			"reply_comment_id":{
				"type": "keyword"
			},
			"content":{
				"type": "keyword"
			},
			"kind":{
				"type": "short"
			},
			"is_praise":{
				"type": "short"
			},
			"likes_nums":{
				"type": "integer"
			},
			"comment_nums":{
				"type": "integer"
			},
			"state":{
				"type": "short"
			},
			"created_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"updated_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			}
		}
	}
}`

type EggFriendCircleCommentEs struct {
	Uid               int64  `json:"uid" label:"uid"`
	ImUid             int64  `json:"im_uid" label:"im_uid"`
	Kind              int32  `json:"kind"  label:"类型(1:普通 2:官方)"`
	CircleId          string `json:"circle_id" label:"朋友圈id"`
	CommentId         string `json:"comment_id" label:"评论id"`
	CommentImUid      int64  `json:"comment_im_uid" label:"回复评论用户id"`
	ReplyCommentId    string `json:"reply_comment_id" label:"回复评论id"`
	ReplyCommentImUid int64  `json:"reply_comment_im_uid" label:"回复评论用户id"`
	Content           string `json:"content" label:"文本内容"`
	LikesNums         int    `json:"likes_nums" label:"点赞数"`
	CommentNums       int    `json:"comment_nums" label:"评论数"`
	State             int32  `json:"state" label:"状态(1:正常 2:隐藏)"`
	IsPraise          int32  `json:"is_praise" label:"是否被表扬(1:是 2:否)"`
	CreatedAt         string `json:"created_at"`
	UpdatedAt         string `json:"updated_at"`
}

//const EggFriendCircleCommentLikeEsAlias = "egg_friend_circle_comment_like"
//const EggFriendCircleCommentLikeEsIndex = "egg_friend_circle_comment_like_"
//const EggFriendCircleCommentLikeEsMapping = `
//{
//	"settings" : {
//      "number_of_shards" : 2,
//      "number_of_replicas" : 1
//    },
//    "aliases": {
//      "egg_friend_circle_comment": {}
//	},
//	"mappings":{
//		"properties":{
//			"uid":{
//				"type": "integer"
//			},
//			"im_uid":{
//				"type": "integer"
//			},
//			"comment_id":{
//				"type": "integer"
//			},
//			"created_at":{
//				"type": "date",
//         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
//			},
//			"updated_at":{
//				"type": "date",
//         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
//			}
//		}
//	}
//}`
//
//type EggFriendCircleCommentLikeEs struct {
//	Uid       int64  `json:"uid" label:"uid"`
//	ImUid     int64  `json:"im_uid" label:"im_uid"`
//	CommentId         string `json:"comment_id" label:"评论id"`
//	CreatedAt string `json:"created_at"`
//	UpdatedAt string `json:"updated_at"`
//}

const EggFriendCircleLikeEsAlias = "egg_friend_circle_like"
const EggFriendCircleLikeEsIndex = "egg_friend_circle_like_"
const EggFriendCircleLikeEsMapping = `
{ 
	"settings" : {
      "number_of_shards" : 2,
      "number_of_replicas" : 1 
    },
    "aliases": {
      "egg_friend_circle_like": {}
	},
	"mappings":{
		"properties":{
			"uid":{
				"type": "integer"
			},
			"circle_id":{
				"type": "keyword"
			},
			"created_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"updated_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			}
		}
	}
}`

type EggFriendCircleLikeEs struct {
	Uid       int64  `json:"uid" label:"uid"`
	ImUid     int64  `json:"im_uid" label:"im_uid"`
	CircleId  string `json:"circle_id" label:"朋友圈id"`
	CreatedAt string `json:"created_at"`
	UpdatedAt string `json:"updated_at"`
}
