package egg_energy

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/implement"
	"code.fnuoos.com/EggPlanet/egg_system_rules.git/enum"
	md2 "code.fnuoos.com/EggPlanet/egg_system_rules.git/md"
	"code.fnuoos.com/EggPlanet/egg_system_rules.git/rule"
	"code.fnuoos.com/EggPlanet/egg_system_rules.git/rule/egg_energy/md"
	egg_system_rules "code.fnuoos.com/EggPlanet/egg_system_rules.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_system_rules.git/utils/logx"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_mq.git/rabbit"
	"errors"
	"fmt"
	"github.com/shopspring/decimal"
	"math/rand"
	"time"
	"xorm.io/xorm"
)

// ActivityCoinAutoExchangeEggPersonEnergy 个人蛋蛋积分【开始】兑换成个人蛋蛋能量
func ActivityCoinAutoExchangeEggPersonEnergy(engine *xorm.Engine, req md.EggEnergyStructForAutoExchangeGreenEnergy) (err error) {
	//1、判断当前是否可以执行
	now := time.Now()
	endTimeValue, _ := egg_system_rules.StringToTime(req.EndExchangeTime)
	if endTimeValue.After(now) {
		seconds := time.Duration(rand.Intn(10))
		fmt.Println("休眠:::::", seconds)
		time.Sleep(time.Second * seconds) //TODO::随机休眠10s不等
		return errors.New("未到可执行时间~~~")
	}

	//2、查询sign 记录
	eggSignInDb := implement.NewEggSignInDb(engine)
	sign, err := eggSignInDb.EggSignInGet(req.SignId)
	if err != nil {
		return err
	}
	if sign.IsCompleted == 1 {
		//TODO::已完成的直接pass
		return
	}

	//3、增加用户对应蛋蛋能量数量
	startTime, _ := egg_system_rules.StringToTime(sign.StartTime)
	endTime, _ := egg_system_rules.StringToTime(sign.EndTime)
	seconds := endTime.Sub(startTime).Seconds()
	secondsValue := decimal.NewFromFloat(seconds)
	eggEnergyNumsForPersonValue, _ := decimal.NewFromString(sign.EstimatePerSecondPersonEggEnergyValue)
	eggEnergyNumsForTeamValue, _ := decimal.NewFromString(sign.EstimatePerSecondTeamEggEnergyValue)
	amountForPerson, _ := eggEnergyNumsForPersonValue.Mul(secondsValue).Float64()
	amountForTeam, _ := eggEnergyNumsForTeamValue.Mul(secondsValue).Float64()
	session := engine.NewSession()
	defer func() {
		session.Close()
		if err := recover(); err != nil {
			_ = zhios_order_relate_logx.Error(err)
		}
	}()
	session.Begin()
	err = rule.DealUserVirtualCoin(session, md2.DealUserVirtualCoinReq{
		Kind:         "add",
		Title:        enum.PersonEggGetByEnergyEggPointCoin.String(),
		TransferType: int(enum.PersonEggGetByEnergyEggPointCoin),
		CoinId:       req.PersonEggEnergyCoinId,
		Uid:          req.Uid,
		Amount:       amountForPerson,
	})
	if err != nil {
		fmt.Println("ActivityCoinAutoExchangeEggEnergy:::::err111:::", err)
		_ = session.Rollback()
		return
	}
	if amountForTeam > 0 {
		err = rule.DealUserVirtualCoin(session, md2.DealUserVirtualCoinReq{
			Kind:         "add",
			Title:        enum.TeamEggGetByEnergyEggPointCoin.String(),
			TransferType: int(enum.TeamEggGetByEnergyEggPointCoin),
			CoinId:       req.TeamEggEnergyCoinId,
			Uid:          req.Uid,
			Amount:       amountForTeam,
		})
		if err != nil {
			fmt.Println("ActivityCoinAutoExchangeEggEnergy:::::err222:::", err)
			_ = session.Rollback()
			return
		}
	}

	//3、修改sign记录
	sign.IsCompleted = 1
	_, err = eggSignInDb.EggSignInUpdateBySession(session, sign.Id, sign, "is_completed")
	if err != nil {
		fmt.Println("ActivityCoinAutoExchangeEggEnergy:::::err333:::", err)
		_ = session.Rollback()
		return err
	}

	err = session.Commit()
	if err != nil {
		session.Rollback()
		return err
	}

	// 推入队列中异步处理
	ch, err1 := rabbit.Cfg.Pool.GetChannel()
	if err1 != nil {
		return err1
	}
	defer ch.Release()
	ch.Publish(md.EggAppExchange, egg_system_rules.SerializeStr(md.EggStructForRecordActiveData{
		Uid:                  req.Uid,
		TotalPersonEggPoints: sign.TotalPersonEggPoints,
	}), md.EggRoutKeyForRecordActive)

	return nil
}
